Crate rustmex_core

source ·

Re-exports

Modules

  • Distinghuising matlab types from eachother
  • Conversion to and from matlab with associated errors
  • map for heterogenous structures. Internal Rustmex tooling.
  • Numeric array and numeric data handling
  • Module defining how Matlab pointers behave
  • Implementations on the raw mxArray pointer.
  • Signatures of shim functions between Rustmex and the used backend.

Macros

  • Create an mxArray of a specified shape, type, and complexity, without a backing array. Internal Rustmex tool.
  • Macro to construct a valid pointer for slice construction. Internal Rustmex tool.
  • Given some data and a shape, check whether the size is okay. Internal Rustmex tool.
  • Convert a numeric NDarray to a numeric MxArray. Internal Rustmex tool.
  • Convert a numeric mxArray to a numeric NDarray. Internal Rustmex tool.
  • Write out the definition for a numerical structure. Internal Rustmex tool.
  • Check whether a shape is okay. Internal Rustmex tool

Enums

  • Flag for whether a real or complex numeric array should be created.

Traits

  • Base Matlab class trait. Matlab classes, in Rustmex, are wrapper structures around a bare MatlabPtr, giving them some type information.
  • Denotes whether the Matlab class is mutable.
  • Some, but not all types, can be created in an empty state; whether they can is denoted by this trait.
  • Denotes whether a Matlab class owns its data.
  • Only some Matlab classes, i.e the numeric classes, have data that can be meaningfully taken out of the backing MutMatlabPtr.