Module rustmex_core::pointers
source · Expand description
Module defining how Matlab pointers behave
Structs
- The owned variant of an mxArray. Some of Matlab’s mex functions specify that the caller is responsible for deallocating the object when it is done with it, unless the object in question is returned to Matlab. This cannot be expressed with just (mutable) references, so this type implements the owned type.
Traits
- A Matlab Pointer is a marker trait, used to be generic over pointers which can be used across API boundaries with Matlab. Two of these are already implemented (Matlab returns an opaque pointer to objects, so these can just be used as-is as references), which leaves the third — the owned type — to be implemented. See
MxArray.